# automatically generated by the FlatBuffers compiler, do not modify

# namespace: openmeteo_sdk

from enum import IntEnum

class Model(IntEnum):
    undefined = 0
    best_match = 1
    gfs_seamless = 2
    gfs_global = 3
    gfs_hrrr = 4
    meteofrance_seamless = 5
    meteofrance_arpege_seamless = 6
    meteofrance_arpege_world = 7
    meteofrance_arpege_europe = 8
    meteofrance_arome_seamless = 9
    meteofrance_arome_france = 10
    meteofrance_arome_france_hd = 11
    jma_seamless = 12
    jma_msm = 13
    jms_gsm = 14
    jma_gsm = 15
    gem_seamless = 16
    gem_global = 17
    gem_regional = 18
    gem_hrdps_continental = 19
    icon_seamless = 20
    icon_global = 21
    icon_eu = 22
    icon_d2 = 23
    ecmwf_ifs04 = 24
    metno_nordic = 25
    era5_seamless = 26
    era5 = 27
    cerra = 28
    era5_land = 29
    ecmwf_ifs = 30
    gwam = 31
    ewam = 32
    glofas_seamless_v3 = 33
    glofas_forecast_v3 = 34
    glofas_consolidated_v3 = 35
    glofas_seamless_v4 = 36
    glofas_forecast_v4 = 37
    glofas_consolidated_v4 = 38
    gfs025 = 39
    gfs05 = 40
    CMCC_CM2_VHR4 = 41
    FGOALS_f3_H_highresSST = 42
    FGOALS_f3_H = 43
    HiRAM_SIT_HR = 44
    MRI_AGCM3_2_S = 45
    EC_Earth3P_HR = 46
    MPI_ESM1_2_XR = 47
    NICAM16_8S = 48
    cams_europe = 49
    cams_global = 50
    cfsv2 = 51
