# automatically generated by the FlatBuffers compiler, do not modify

# namespace: openmeteo_sdk

from enum import IntEnum

class Variable(IntEnum):
    undefined = 0
    apparent_temperature = 1
    cape = 2
    cloud_cover = 3
    cloud_cover_high = 4
    cloud_cover_low = 5
    cloud_cover_mid = 6
    daylight_duration = 7
    dew_point = 8
    diffuse_radiation = 9
    diffuse_radiation_instant = 10
    direct_normal_irradiance = 11
    direct_normal_irradiance_instant = 12
    direct_radiation = 13
    direct_radiation_instant = 14
    et0_fao_evapotranspiration = 15
    evapotranspiration = 16
    freezing_level_height = 17
    growing_degree_days = 18
    is_day = 19
    latent_heat_flux = 20
    leaf_wetness_probability = 21
    lifted_index = 22
    lightning_potential = 23
    precipitation = 24
    precipitation_hours = 25
    precipitation_probability = 26
    pressure_msl = 27
    rain = 28
    relative_humidity = 29
    runoff = 30
    sensible_heat_flux = 31
    shortwave_radiation = 32
    shortwave_radiation_instant = 33
    showers = 34
    snow_depth = 35
    snow_height = 36
    snowfall = 37
    snowfall_height = 38
    snowfall_water_equivalent = 39
    sunrise = 40
    sunset = 41
    soil_moisture = 42
    soil_moisture_index = 43
    soil_temperature = 44
    surface_pressure = 45
    surface_temperature = 46
    temperature = 47
    terrestrial_radiation = 48
    terrestrial_radiation_instant = 49
    total_column_integrated_water_vapour = 50
    updraft = 51
    uv_index = 52
    uv_index_clear_sky = 53
    vapour_pressure_deficit = 54
    visibility = 55
    weather_code = 56
    wind_direction = 57
    wind_gusts = 58
    wind_speed = 59
    vertical_velocity = 60
    geopotential_height = 61
    wet_bulb_temperature = 62
    river_discharge = 63
    wave_height = 64
    wave_period = 65
    wave_direction = 66
    wind_wave_height = 67
    wind_wave_period = 68
    wind_wave_peak_period = 69
    wind_wave_direction = 70
    swell_wave_height = 71
    swell_wave_period = 72
    swell_wave_peak_period = 73
    swell_wave_direction = 74
    pm10 = 75
    pm2p5 = 76
    dust = 77
    aerosol_optical_depth = 78
    carbon_monoxide = 79
    nitrogen_dioxide = 80
    ammonia = 81
    ozone = 82
    sulphur_dioxide = 83
    alder_pollen = 84
    birch_pollen = 85
    grass_pollen = 86
    mugwort_pollen = 87
    olive_pollen = 88
    ragweed_pollen = 89
    european_aqi = 90
    european_aqi_pm2p5 = 91
    european_aqi_pm10 = 92
    european_aqi_nitrogen_dioxide = 93
    european_aqi_ozone = 94
    european_aqi_sulphur_dioxide = 95
    us_aqi = 96
    us_aqi_pm2p5 = 97
    us_aqi_pm10 = 98
    us_aqi_nitrogen_dioxide = 99
    us_aqi_ozone = 100
    us_aqi_sulphur_dioxide = 101
    us_aqi_carbon_monoxide = 102
