# automatically generated by the FlatBuffers compiler, do not modify

# namespace: openmeteo_sdk

from enum import IntEnum

class Unit(IntEnum):
    undefined = 0
    celsius = 1
    centimetre = 2
    cubic_metre_per_cubic_metre = 3
    cubic_metre_per_second = 4
    degree_direction = 5
    dimensionless_integer = 6
    dimensionless = 7
    european_air_quality_index = 8
    fahrenheit = 9
    feet = 10
    fraction = 11
    gdd_celsius = 12
    geopotential_metre = 13
    grains_per_cubic_metre = 14
    gram_per_kilogram = 15
    hectopascal = 16
    hours = 17
    inch = 18
    iso8601 = 19
    joule_per_kilogram = 20
    kelvin = 21
    kilopascal = 22
    kilogram_per_square_metre = 23
    kilometres_per_hour = 24
    knots = 25
    megajoule_per_square_metre = 26
    metre_per_second_not_unit_converted = 27
    metre_per_second = 28
    metre = 29
    micrograms_per_cubic_metre = 30
    miles_per_hour = 31
    millimetre = 32
    pascal = 33
    per_second = 34
    percentage = 35
    seconds = 36
    unix_time = 37
    us_air_quality_index = 38
    watt_per_square_metre = 39
    wmo_code = 40
