# automatically generated by the FlatBuffers compiler, do not modify

# namespace: openmeteo_sdk

from enum import IntEnum

class Aggregation(IntEnum):
    none = 0
    minimum = 1
    maximum = 2
    mean = 3
    p10 = 4
    p25 = 5
    median = 6
    p75 = 7
    p90 = 8
    dominant = 9
    sum = 10
